# TinyCircuits SX1505 Python

This repository holds a python package and examples meant for using the TinyCircuits [Joystick Wireling](https://tinycircuits.com/collections/wireling-input-output/products/joystick-wireling) and [Rotary Wireling](https://tinycircuits.com/collections/wireling-input-output/products/rotary-switch-wireling) with a Raspberry Pi and Wireling Pi Hat.

To install the package, use:

```
pip3 install tinycircuits-sx1505
```

or if your default is Python 3:

```
pip install tinycircuits-sx1505
```

Software written by: [TinyCircuits](https://tinycircuits.com/) for use with TinyCircuits hardware 
